<?php

use Phinx\Migration\AbstractMigration;
use Phinx\Db\Adapter\MysqlAdapter;

class AddBack extends AbstractMigration
{
    public function change()
    {
        $this
            ->table("back_actif", ['id' => false, 'primary_key' => ["actif_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('actif_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('actif_nom', 'string', ['null' => true, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'actif_id'])
            ->create();

        $this
            ->table("back_administrateur", ['id' => false, 'primary_key' => ["administrateur_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('administrateur_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('administrateur_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'administrateur_id'])
            ->addColumn('administrateur_prenom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'administrateur_nom'])
            ->addColumn('administrateur_email', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'administrateur_prenom'])
            ->addColumn('administrateur_password', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'administrateur_email'])
            ->addColumn('administrateur_token', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'administrateur_password'])
            ->addColumn('actif_id', 'integer', ['null' => false, 'default' => 2, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'administrateur_token', 'signed' => false])
            ->addForeignKey('actif_id', 'back_actif', 'actif_id', array(
                'delete' => 'RESTRICT',
                'update' => 'RESTRICT'
            ))
            ->addIndex(['administrateur_email'], ['name' => "administrateur_email", 'unique' => true])
            ->addIndex(['actif_id'], ['name' => "actif_id", 'unique' => false])
            ->create();

        $this
            ->table("back_module", ['id' => false, 'primary_key' => ["module_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('module_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('module_parent_id', 'integer', ['null' => true, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'module_id', 'signed' => false])
            ->addColumn('module_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_parent_id', 'comment' => "Fil d'arianne"])
            ->addColumn('module_titre', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_nom', 'comment' => "Menu"])
            ->addColumn('module_page', 'string', ['null' => true, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_titre', 'comment' => "Nom de la classe"])
            ->addColumn('module_rang', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'module_page'])
            ->addColumn('actif_id', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'module_rang', 'signed' => false])
            ->addColumn('module_order', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'actif_id'])
            ->addColumn('module_group', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_order'])
            ->addColumn('module_limit', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'comment' => "Limit par défaut", 'after' => 'module_group'])
            ->addColumn('module_bases', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_limit'])
            ->addColumn('module_icon', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_bases'])
            ->addForeignKey('actif_id', 'back_actif', 'actif_id', array(
                'delete' => 'RESTRICT',
                'update' => 'RESTRICT'
            ))
            ->addForeignKey('module_parent_id', 'back_module', 'module_id', array(
                'delete' => 'SET NULL',
                'update' => 'CASCADE'
            ))
            ->addIndex(['module_parent_id'], ['name' => "module_parent_id", 'unique' => false])
            ->addIndex(['actif_id'], ['name' => "actif_id", 'unique' => false])
            ->addIndex(['module_page'], ['unique' => true])
            ->addIndex(['module_rang'], ['unique' => false])
            ->create();

        $this
            ->table("back_administrateur_droit", ['id' => false, 'primary_key' => ["administrateur_droit_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('administrateur_droit_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('administrateur_id', 'integer', ['null' => false, 'default' => NULL, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'administrateur_droit_id', 'signed' => false])
            ->addColumn('module_id', 'integer', ['null' => true, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'administrateur_id', 'signed' => false])
            ->addColumn('administrateur_droit_somme', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'module_id'])
            ->addForeignKey('administrateur_id', 'back_administrateur', 'administrateur_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('module_id', 'back_module', 'module_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['administrateur_id'], ['name' => "groupe_id", 'unique' => false])
            ->addIndex(['module_id'], ['name' => "module_id", 'unique' => false])
            ->addIndex(['module_id', 'administrateur_id'], ['unique' => true])
            ->create();

        $this
            ->table("back_groupe", ['id' => false, 'primary_key' => ["groupe_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('groupe_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('groupe_code', 'string', ['null' => false, 'default' => '', 'limit' => 10, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'groupe_id'])
            ->addColumn('groupe_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'groupe_code'])
            ->addColumn('groupe_rang', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'groupe_nom'])
            ->addIndex('groupe_rang', ['unique' => false])
            ->create();

        $this
            ->table("back_administrateur_groupe", ['id' => false, 'primary_key' => ["administrateur_groupe_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('administrateur_groupe_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('administrateur_id', 'integer', ['null' => false, 'default' => NULL, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'administrateur_groupe_id', 'signed' => false])
            ->addColumn('groupe_id', 'integer', ['null' => false, 'default' => NULL, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'administrateur_id', 'signed' => false])
            ->addForeignKey('groupe_id', 'back_groupe', 'groupe_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('administrateur_id', 'back_administrateur', 'administrateur_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['groupe_id'], ['name' => "groupe_id", 'unique' => false])
            ->addIndex(['administrateur_id'], ['name' => "administrateur_id", 'unique' => false])
            ->addIndex(['groupe_id', 'administrateur_id'], ['unique' => true])
            ->create();

        $this
            ->table("back_droits", ['id' => false, 'primary_key' => ["droit_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('droit_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('droit_code', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'droit_id'])
            ->addColumn('droit_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'droit_code'])
            ->addColumn('droit_valeur', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'droit_nom'])
            ->addIndex(['droit_code'], ['name' => "droit_code", 'unique' => true])
            ->create();

        $this
            ->table("back_groupe_droit", ['id' => false, 'primary_key' => ["groupe_droit_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('groupe_droit_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('groupe_id', 'integer', ['null' => false, 'default' => NULL, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'groupe_droit_id', 'signed' => false])
            ->addColumn('module_id', 'integer', ['null' => true, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'groupe_id', 'signed' => false])
            ->addColumn('groupe_droit_somme', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'module_id'])
            ->addForeignKey('groupe_id', 'back_groupe', 'groupe_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('module_id', 'back_module', 'module_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['groupe_id'], ['name' => "groupe_id", 'unique' => false])
            ->addIndex(['module_id'], ['name' => "module_id", 'unique' => false])
            ->addIndex(['groupe_id', 'module_id'], ['unique' => true])
            ->create();
        
        $this
            ->table("back_module_export", ['id' => false, 'primary_key' => ["module_export_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('module_export_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('module_id', 'integer', ['null' => false, 'default' => NULL, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'module_export_id', 'signed' => false])
            ->addColumn('module_export_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_id'])
            ->addColumn('module_export_type', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_export_nom'])
            ->addColumn('module_export_methode', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_export_type'])
            ->addColumn('module_export_rang', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'module_export_methode'])
            ->addColumn('module_export_alert', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_export_rang'])
            ->addColumn('module_export_out', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_export_alert'])
            ->addColumn('module_export_mini', 'string', ['null' => false, 'default' => '', 'limit' => 4, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'module_export_out'])
            ->addColumn('module_export_import', 'integer', ['null' => false, 'default' => '0', 'limit' => MysqlAdapter::INT_TINY, 'precision' => 3, 'after' => 'module_export_mini'])
            ->addForeignKey('module_id', 'back_module', 'module_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['module_id'], ['name' => "module_id", 'unique' => false])
            ->addIndex(['module_export_rang'], ['unique' => false])
            ->addIndex(['module_export_import'], ['unique' => false])
            ->create();
    }
}
