<?php

namespace Controller;

use Application;
use Categorie;
use Breadcrumb;
use Cms;
use Produit;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Annotation\Route;
use \Symfony\Component\Routing\Route as BaseRoute;
use Symfony\Component\Routing\Router;


/**
 * Class SitemapController
 * @package Controller
 *
 * @Route("")
 */
class SitemapController extends Controller
{
    /** @var array $options */
    private static $options = [
        'loc', 'priority', 'changefreq'
    ];

    /** @var Router $router */
    private $router;

    public function __construct(Request $request)
    {
        parent::__construct($request);
        $this->router = Application::getRouter()->getRouter();
    }

    /**
     * @Route("/sitemap.html", name="sitemap", methods = { "GET" })
     */

    public function sitemap()
    {
        $texte = new \Texte();
        $bc = Breadcrumb::getInstance();
        $bc->add( $texte->getOneOrCreate("plan_du_site", "Plan du site") ,$this->generateUrl('sitemap'));

        $cms = new Cms();
        $arrPages = $cms->get();
        $this->template->assign('arrPages', $arrPages);

        $categorie = new Categorie();
        $categories = $categorie->get();
        $arrCategories = \Tools::buildTree($categories, 'categorie_id');
        $this->template->assign('categories', $arrCategories);

        return $this->render('sitemap.tpl');
    }

    /**
     * @Route("/sitemap.xml", name="sitemapxml", methods = { "GET" })
     */
    public function sitemapXML()
    {
        $this->template->assign('urls', $this->generateFromRouting());

        $cms = new Cms();
        $arrPages = $cms->get();
        $this->template->assign('arrPages', $arrPages);

        $categorie = new Categorie();
        $categories = $categorie->get();
        $arrCategories = \Tools::buildTree($categories, 'categorie_id');
        $this->template->assign('arrCategories', $arrCategories);

        $produit = new Produit();
        $arrProduits = $produit->getSearch();
        $this->template->assign('arrProduits',$arrProduits);

        $site_url = substr(SITE_URL,0,strlen(SITE_URL)-1);
        $this->template->assign('site_url',$site_url);

        $response = $this->fetch('sitemapXML.tpl');
        $response->headers->set('Content-type', "text/xml");

        return $response;
    }

    /**
     * @return array
     */
    private function generateFromRouting()
    {
        $return = array();
        $routes = $this->router->getRouteCollection()->all();

        $sitemapRoutes = array_filter($routes, function (BaseRoute $route) {
            return $route->hasOption('_sitemap');
        });

        foreach ($sitemapRoutes as $name => $sitemapRoute) {
            $sitemapRouteOptions = $sitemapRoute->getOption('_sitemap');

            $route = array_intersect_key($sitemapRouteOptions, array_flip(self::$options));
            if(!array_key_exists('loc', $route)){
                $route['loc'] = $this->router->generate($name, [], Router::ABSOLUTE_URL);
            }
            $return[] = $route;
        }

        return $return;
    }
}