<?php

namespace ProduitList;

use Produit;

abstract class ProduitList extends \Model
{
    protected $table = "produit_list";

    /**
     * @var array
     */
    protected $produits;

    public function __construct($id = null)
    {
        $this->produits = array();
        $this->produit_list_type_id = $this->typeId;
        parent::__construct($id);
    }

    /**
     * Récupère les listes
     * @param array $formvars
     * @return array
     */
    public function getList($formvars = array())
    {
        $query = new \Query();
        $query->select('*')
            ->from('produit_list')
            ->where('produit_list_delete = 0');

        if (!empty($formvars['client_id'])){
            $query->where('client_id', $formvars['client_id']);
        }
        if (!empty($formvars['produit_list_id'])){
            $query->where('produit_list_id', $formvars['produit_list_id']);
        }

        $query->order('produit_list_id DESC');

        return $this->sql->getAll($query->build());
    }

    /**
     * Récupère les listes avec les produits
     * @param array $formvars
     * @return array
     */
    public function getListDetail($formvars = array())
    {
        $arrLists = $this->getList($formvars);

        foreach ($arrLists as $key =>$list) {
            $infosList = $this->getInfosList($list['produit_list_id']);
            $arrLists[$key] = array_merge($list,$infosList);
        }

        return $arrLists;
    }

    /**
     * Récupère des totaux et des produits pour une liste
     * @param $produitListId
     * @return array
     */
    public function getInfosList($produitListId)
    {
        $this->produit_list_id = $produitListId;
        $totalHT = 0;
        $totalTTC = 0;
        $totalQte = 0;
        $arrProduits = $this->getProduitsDetail($produitListId);

        foreach($arrProduits as $p){
            $totalQte += $p['produit_list_produit_qte'];
            $totalHT += ($p['produit_prix_ht'] * $p['produit_list_produit_qte']);
            $totalTTC += ($p['produit_prix_ttc']* $p['produit_list_produit_qte']);
        }

        return array(
            'total_ht' => $totalHT,
            'total_ttc' => $totalTTC,
            'total_qte' => $totalQte,
            'produits' => $arrProduits
        );
    }

    /**
     * Récupère des infos des infos produits
     * @param $produitListId
     * @return array
     */
    public function getProduitsDetail($produitListId)
    {
        $this->produit_list_id = $produitListId;
        $arrProduitsList = $this->getProduits(array('produit_list_id' => $produitListId));
        $arrResult = array();
        $produit = new Produit();

        foreach($arrProduitsList as $prod){

            $arrProduit  = $produit->getOne($prod);
            if (!empty($arrProduit)){
                $arrProduit['produit_list_produit_qte'] = $prod['produit_list_produit_qte'];
                $arrResult[] = $arrProduit;
            }
        }

        return $arrResult;
    }

    /**
     * Récupère les produits de la liste
     * @param array $formvars
     * @return array
     */
    public function getProduits($formvars = array())
    {
        $query = new \Query();
        $query->select()->from('produit_list_produit')->extras($formvars);

        if (!empty($this->produit_list_id)) {
            $query->where('plp.produit_list_id', $this->produit_list_id);
            $result = $this->sql->getAll($query->build());
        } else {
            $result = array();
        }

        return $result;
    }

    /**
     * @param null $data
     * @return mixed
     * @throws \DediException
     */
    public function save($data = null)
    {
        $id = parent::save($data);

        foreach ($this->produits as $produit) {
            $produit['produit_list_id'] = $id;
            if (!empty($produit['quantite_order'])) {
                $produit['produit_list_produit_qte'] = $produit['quantite_order'];
            }
            $this->sql->save('produit_list_produit', $produit);
        }

        return $id;
    }

    /**
     * @throws \Exception
     */
    public function delete()
    {
        $this->produit_list_delete = 1;

        parent::save();
    }
}